Pērciet Ford Mondeo 2017 2.0 180 hp TITANIUM 2017 ar patiesu nobraukumu 76203 km Rīgā oficiālā dīlera salonā
Description: Iegādājaties mazlietotu Ford Mondeo ar nobraukumu 76203 km. Mazlietots Ford Mondeo 2017 2.0 180 hp TITANIUM Automātiskā par 22990 EUR, mazlietotu automobiļu tirdzniecības vietā Inchcape Certified Rīgā.

# Ford Mondeo 2017 2.0 180 hp TITANIUM, 76 203 km

16
ATLAIDE 1 400 €
21 590 €
(Ieskaitot PVN 21%)
22 990 €
no € 227.83 / mēn.*

- Izlaiduma gads
  2017
- Virsbūves tips
  Universālis
- Nobraukums
  76 203 km

- Piedziņas veids
  FWD
- Dzinējs
  Dīzeļdegviela
- Pārnesumkārba
  Automātiskā
- Dzinēja tilpums
  1998 cm3

##### JAUNUMS!

Apskatiet auto tiešsaistē, neizejot no mājām, vai sazinieties ar mums caur Whatsapp

Sazināties Whatsapp

- Tehniskie dati
- Aprīkojums
- Pamatinformācija

- Zīmols
  Ford
- Modelis
  Mondeo
- Modifikācija
  2017 2.0 180 hp TITANIUM
- Nobraukums
  76 203 km

- VIN
  WF0FXXWPCFGA22145
- Izlaiduma gads
  2017
- Virsbūves tips
  Universālis
- Piedziņas veids
  FWD
- Pārnesumkārba
  Automātiskā

- Informācijas sistēmas
- Papildus aprīkojums
- Interjers
- Drošība
- Komforts

- Skārienekrāns
- Audiosistēma
- LCD ekrāns (priekšā)

- Borta dators
- Brīvroku sistēma

- Vieglmetāla diski
- Riepu spiediena kontrole
- Jumta reliņi

- Āra temperatūras mērītājs
- Apsildāms vējstikls
- Servisa grāmatiņa

- Otra atslēga (2)

- Elektriski regulējami sēdekļi (priekšējie)
- Regulējams stūres novietojums (augstumā un dziļumā)
- Multistūre

- Apsildāmi sēdekļi (priekšējie)
- Regulējama sēdekļu muguras daļa (vadītāja, pasažiera)
- Salona apgaismojums

- Stūres pastiprinātājs
- Centrālā atslēga
- ABS pretbloķēšanas sistēma

- Gaisa spilveni
- Isofix bērnu sēdeklīšu stiprinājumi (aizmugurējos sēdekļos)
- LED lukturi

- Miglas lukturi (priekšējie)

- Klimata kontrole
- Elektriski regulējami sānu spoguļi (apsildāmi)
- Elektriski atverami/aizverami stikli

- Kruīza kontrole
- Parkošanās kamera
- Parkošanās sensori (priekšējie, aizmugurejie)

- Salona gaisa filtrs

## Priekšlīzinga kalkulators

Vēlaties iegādāties jaunu ikdienas sabiedroto ar līzingu?
Mēs par to esam padomājuši.
Aizpildiet šo īso pieteikuma formu un noskaidrojiet savas iespējas iegādāties auto līzingā.

Finanšu līzings

no € / mēn.*

Līzinga periods, gadi:

3 4 5 6 7

Pirmā iemaksa:

EUR
10% 20% 30% 40% 50%

Inchcape Motors Latvia SIA piedāvā finansējumu sadarbībā ar vadošajām līzinga kompānijām.

Aprēķins veikts, ņemot vērā izvēlēta automobiļa cenu finanšu līzingā ar % iemaksu uz mēnešiem.

Procentu likme 2,95% + EURIBOR (6 mēn.), administrēšanas maksa 1,5%.Aizņemies atbildīgi, izvērtējot savas iespējas atmaksāt.

Līzinga kalkulatoram ir informatīva nozīme.

Operatīvais līzings

no € / mēn.*

Līzinga periods, gadi:

3 4 5

Pirmā iemaksa:

EUR
10% 20% 30% 40% 50%

Atlikusī vērtība:

15% 20% 25% 30% 35%

Inchcape Motors Latvia SIA piedāvā finansējumu sadarbībā ar vadošajām līzinga kompānijām.

Aprēķins veikts, ņemot vērā izvēlēta automobiļa cenu operatīvajā līzingā ar % iemaksu uz mēnešiem ar % atlikušo vērtību un 100 000 km limitu.

Procentu likme 2,95% + EURIBOR (6 mēn.), administrēšanas maksa 1,5%.Aizņemies atbildīgi, izvērtējot savas iespējas atmaksāt.

Līzinga kalkulatoram ir informatīva nozīme un tas var būt atšķirīgs no Jūsu individuālā aprēķina.

## VISLABĀKIE PIEDĀVĀJUMI

ATLAIDE 6 510 €
14

### BMW 318

2019 2.0 110 kW

- 2019

- Sedans

- 38 130 km

- RWD

- Dīzeļdegviela

- Automātiskā

31 990 €
ar PVN
38 500 €
no € 337.58 / mēn.*
ATLAIDE 5 000 €
25

### Land Rover Range Rover Velar

2019 2.0 177 kW S

- 2019

- SUV

- 74 000 km

- AWD

- Dīzeļdegviela

- Automātiskā

47 900 €
ar PVN
52 900 €
no € 505.47 / mēn.*
ATLAIDE 4 200 €
25

### Jaguar F-Pace

2017 2.0 bi-turbo 177 kW F-Pce

- 2017

- SUV

- 133 500 km

- AWD

- Dīzeļdegviela

- Automātiskā

28 700 €
ar PVN
32 900 €
no € 302.86 / mēn.*
ATLAIDE 3 810 €
11

### Volvo S90

2017 2.0 FWD 110 kW

- 2017

- Sedans

- 134 000 km

- FWD

- Dīzeļdegviela

- Automātiskā

27 490 €
ar PVN
31 300 €
no € 290.09 / mēn.*
ATLAIDE 3 810 €
16

### Volkswagen Golf Sportsvan

2015 1.4 92 kW

- 2015

- Hečbeks

- 75 600 km

- FWD

- Benzīns

- Mehāniskā

11 990 €
ar PVN
15 800 €
no € 126.53 / mēn.*
ATLAIDE 3 700 €
20

### Mercedes-Benz c220

2018 2.2 RWD 125 kW T-mod

- 2018

- Universālis

- 143 088 km

- RWD

- Dīzeļdegviela

- Automātiskā

21 290 €
ar PVN
24 990 €
no € 224.67 / mēn.*

## Kāpēc iegādāties automašīnu Inchcape Certified ?

#### Padziļināta un kvalitatīva tehniskā pārbaude

Automašīnas tiek pārbaudītas atbilstoši stingriem Inchcape Certified standartiem

#### Visaptverošs, profesionālu pakalpojumu klāsts

Finansēšana, apdrošināšana, testa braucieni, un citi pakalpojumi pieejami uz vietas

#### 6 mēnešu garantija

Sešu mēnešu garantija visām automašīnām no Inchcape Certified

#### Jūsu automašīnas atpirkums (Trade-In)

Jūsu automašīna var kalpot kā pirmā iemaksa

Pieprasīt zvanu
Apliecinu, ka esmu iepazinies un piekrītu Inchcape Motors Latvia Privātuma politikai Piekrītu, ka ar mani sazinās izrādītās intereses ietvaros, izmantojot manis norādīto kontaktinformāciju Piekrītu saņemt informāciju par īpašajiem piedāvājumiem, piemēram, servisa un rezerves daļu akcijām, izpārdošanām un sezonas piedāvājumiem, kā arī aksesuāru, jaunu un mazlietotu automašīnu piedāvājumiem no Inchcape Motors Latvia SIA, kā arī citus piedāvājumus e-pasta, SMS un zvana veidā.
Rezervē savu vizītes laiku!

Piesaki vizīti kādā no trim Inchcape Certified autosaloniem ātri un ērti!

Apliecinu, ka esmu iepazinies un piekrītu Inchcape Motors Latvia Privātuma politikai Piekrītu, ka ar mani sazinās izrādītās intereses ietvaros, izmantojot manis norādīto kontaktinformāciju Piekrītu saņemt informāciju par īpašajiem piedāvājumiem, piemēram, servisa un rezerves daļu akcijām, izpārdošanām un sezonas piedāvājumiem, kā arī aksesuāru, jaunu un mazlietotu automašīnu piedāvājumiem no Inchcape Motors Latvia SIA, kā arī citus piedāvājumus e-pasta, SMS un zvana veidā.
Pieteikums ir pieņemts, paldies
Paldies! Jūsu vizītes pieteikums ir saņemts.

Priecāsimies Jūs redzēt Inchcape Certified - pārbaudītu un uzticamu mazlietotu auto salonā!

Pieteikums AutoDNA atskaites saņemšanai
Apliecinu, ka esmu iepazinies un piekrītu Inchcape Motors Latvia Privātuma politikai Piekrītu, ka ar mani sazinās izrādītās intereses ietvaros, izmantojot manis norādīto kontaktinformāciju Piekrītu saņemt informāciju par īpašajiem piedāvājumiem, piemēram, servisa un rezerves daļu akcijām, izpārdošanām un sezonas piedāvājumiem, kā arī aksesuāru, jaunu un mazlietotu automašīnu piedāvājumiem no Inchcape Motors Latvia SIA, kā arī citus piedāvājumus e-pasta, SMS un zvana veidā.

## Pieteikums ONLINE auto apskatei un konsultācijai

Piesakieties automašīnas apskatei un konsultācijai tiešsaistē un gaidiet mūsu pārstāvja zvanu, kura laikā varēsiet vienoties par Jums ērtāko tiešsaistes saziņas kanālu un laiku.

ONLINE saziņas laikā prezentēsim automašīnu, sniegsim ziņas par tās aprīkojumu un tehnisko stāvokli, mūsu pakalpojumiem un finansēšanas iespējām, kā arī atbildes uz visiem Jūsu jautājumiem.

Apliecinu, ka esmu iepazinies un piekrītu Inchcape Motors Latvia Privātuma politikai Piekrītu, ka ar mani sazinās izrādītās intereses ietvaros, izmantojot manis norādīto kontaktinformāciju Piekrītu saņemt informāciju par īpašajiem piedāvājumiem, piemēram, servisa un rezerves daļu akcijām, izpārdošanām un sezonas piedāvājumiem, kā arī aksesuāru, jaunu un mazlietotu automašīnu piedāvājumiem no Inchcape Motors Latvia SIA, kā arī citus piedāvājumus e-pasta, SMS un zvana veidā.
NOSKATĪJI AUTO?
PIESAKTIES BEZMAKSAS TESTA BRAUCIENAM!

Piesaki sev interesējošo automobili testa braucienam un mēs parūpēsimies par laicīgu auto sagatavošanu tieši Tev!

Apliecinu, ka esmu iepazinies un piekrītu Inchcape Motors Latvia Privātuma politikai Piekrītu, ka ar mani sazinās izrādītās intereses ietvaros, izmantojot manis norādīto kontaktinformāciju Piekrītu saņemt informāciju par īpašajiem piedāvājumiem, piemēram, servisa un rezerves daļu akcijām, izpārdošanām un sezonas piedāvājumiem, kā arī aksesuāru, jaunu un mazlietotu automašīnu piedāvājumiem no Inchcape Motors Latvia SIA, kā arī citus piedāvājumus e-pasta, SMS un zvana veidā.

## Uzzini savas auto līzinga iespējas!

Aizpildi līzinga pieteikuma formu neizejot no mājām, un uzzini par savām iespējām iegādāties auto līzingā.

Apliecinu, ka esmu iepazinies un piekrītu Inchcape Motors Latvia Privātuma politikai Piekrītu, ka ar mani sazinās izrādītās intereses ietvaros, izmantojot manis norādīto kontaktinformāciju Piekrītu saņemt informāciju par īpašajiem piedāvājumiem, piemēram, servisa un rezerves daļu akcijām, izpārdošanām un sezonas piedāvājumiem, kā arī aksesuāru, jaunu un mazlietotu automašīnu piedāvājumiem no Inchcape Motors Latvia SIA, kā arī citus piedāvājumus e-pasta, SMS un zvana veidā.

## Uzzini savas auto līzinga iespējas!

Aizpildi līzinga pieteikuma formu neizejot no mājām, un uzzini par savām iespējām iegādāties auto līzingā.

Apliecinu, ka esmu iepazinies un piekrītu Inchcape Motors Latvia Privātuma politikai Piekrītu, ka ar mani sazinās izrādītās intereses ietvaros, izmantojot manis norādīto kontaktinformāciju Piekrītu saņemt informāciju par īpašajiem piedāvājumiem, piemēram, servisa un rezerves daļu akcijām, izpārdošanām un sezonas piedāvājumiem, kā arī aksesuāru, jaunu un mazlietotu automašīnu piedāvājumiem no Inchcape Motors Latvia SIA, kā arī citus piedāvājumus e-pasta, SMS un zvana veidā.
Paņem mašīnu
Apliecinu, ka esmu iepazinies un piekrītu Inchcape Motors Latvia Privātuma politikai Piekrītu, ka ar mani sazinās izrādītās intereses ietvaros, izmantojot manis norādīto kontaktinformāciju Piekrītu saņemt informāciju par īpašajiem piedāvājumiem, piemēram, servisa un rezerves daļu akcijām, izpārdošanām un sezonas piedāvājumiem, kā arī aksesuāru, jaunu un mazlietotu automašīnu piedāvājumiem no Inchcape Motors Latvia SIA, kā arī citus piedāvājumus e-pasta, SMS un zvana veidā.
Pieteikums ir pieņemts, paldies
Pieteikums ir pieņemts, paldies
Paldies! Jūsu pieprasījums ir saņemts.

Priecāsimies Jūs redzēt Inchcape Certified - pārbaudītu un uzticamu mazlietotu auto salonā!

Pieteikums ir pieņemts, paldies
Pieteikums ir pieņemts, paldies
Pieteikums ir pieņemts, paldies